
RELEASE_VERSION='0.0.461022384'
BUILD_DATE='Tue Feb  1 16:01:47 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-02shxt 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2040549026'
GIT_COMMIT_SHA='86dd875717e4b711df7b6f25a5ea08e6f0de438e'
GIT_BRANCH='main'
